 /********************************************************************************
*                                                                               *
*                               Generator                                *
*                                                                               *
*********************************************************************************
* Copyright (C) 2001 by Anastasios Sarris.   All Rights Reserved.             *
*********************************************************************************/
#include "/usr/local/include/fox/fx.h"
#include "MainDialog.h"
#include "ButtonDialog.h"
#include "ArrowDialog.h"
#include "CheckDialog.h"
#include "LabelDialog.h"
#include "RadioDialog.h"
#include "SpinnerDialog.h"
#include "TextFieldDialog.h"
#include "TextDialog.h"
#include "MatrixDialog.h"
#include "ListDialog.h"
#include "ComboDialog.h"
#include "DialDialog.h"
#include "SliderDialog.h"
#include "ToggleButtonDialog.h"
#include "OptionDialog.h"
#include "ListBoxDialog.h"
#include "ScrollBarDialog.h"
#include "GroupDialog.h"
#include "MenuButtonDialog.h"
#include "PopupDialog.h"
#include "HorFrameDialog.h"
#include "VerFrameDialog.h"
#include "SearchDialog.h"
#include "ReplaceDialog.h"
#include "TableDialog.h"
#include "ClassDialog.h"
#include "vars.h"
#include "icons.h"
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#ifndef WIN32
#include <unistd.h>
#endif

/*******************************************************************************/

// Mini application object
class GenWindow : public FXMainWindow
{
	FXDECLARE(GenWindow)

	protected:
		FXMenubar*	menubar;
		FXMenuPane*	filemenu;
		FXMenuPane*	editmenu;
		FXMenuPane*	toolmenu;
		FXMenuPane*	mnuWindows;
		FXMenuPane*	mnuMDIWin;
		FXMenuPane*	mnuMenus;
		FXMenuPane*	mnuColors;
		FXMenuPane* 	mnuCursors;
		FXMenuPane*	mnuIcons;
		FXMenuPane*	mnuFiles;
		FXMenuPane*	mnuFonts;
		FXMenuPane*	mnuDirs;
		FXMenuPane*	mnuBasic;
		FXMenuPane*	mnuLayMan;
		FXMenuPane*	mnuButtons;
		FXMenuPane*	mnuSelectors;
		FXMenuPane*	mnuText;
		FXMenuPane*	mnuIncDec;
		FXMenuPane*	mnuTabs;
		FXMenuPane*	mnuTables;
		FXMenuPane*	mnuScrollers;
		FXMenuPane*	mnuOthers;
		FXMenuPane*	genmenu;
		FXMenuPane*	windowmenu;
		FXMenuPane*	helpmenu;
		
		MainDialog*	dlgMain;
		ButtonDialog*	dlgButton;
		ArrowDialog*	dlgArrow;
		CheckDialog*	dlgCheck;
		LabelDialog*	dlgLabel;
		RadioDialog*	dlgRadio;
		SpinnerDialog*	dlgSpinner;
		TextFieldDialog*	dlgTextField;
		TextDialog*	dlgText;
		MatrixDialog*	dlgMatrix;
		ListDialog*	dlgList;
		ComboDialog*	dlgCombo;
		DialDialog*	dlgDial;
		SliderDialog*	dlgSlider;
		ToggleButtonDialog*	dlgTButton;
		OptionDialog*	dlgOption;
		ListBoxDialog*	dlgListBox;
		ScrollBarDialog*	dlgScrollBar;
		GroupDialog*	dlgGroupBox;
		MenuButtonDialog* dlgMnuButton;
		PopupDialog*	dlgPopup;
		HorFrameDialog*	dlgHorFrame;
		VerFrameDialog*	dlgVerFrame;
		SearchDialog*	dlgSearch;
		ReplaceDialog*	dlgReplace;
		TableDialog*	dlgTable;
		ClassDialog*	dlgClass;
		
		FXTabBook*	tabbook;
		FXMatrix*	toolctrl;
		FXToolbar*	mainTools;
		FXToolbar*	toolbox;
		FXToolbar*	mdiTools;
		FXMDIClient*	mdiclient;
		FXMDIMenu*	mdimenu;
		FXGIFIcon*	mdiicon;
		FXIcon*		genicon;
		FXFont*		mainFont;
		FXList*		sampleLst;
		FXTextField*	txtAdd;
		FXMDIChild* mdiCode;
		FXMDIChild*	mdiSamples;
		FXURL*	Index;
		
		FXbool		stripcr;
		FXString	filename;
		FXString	codeName;
		FXUndoList	undolist;
		FXFileList*	filelist;
		FXRecentFiles	mrufiles;
		FXbool		namechanged;
		FXbool loadFile(const FXString& file);
		FXbool saveFile(const FXString& file);
		FXbool saveChanges();
		
protected:
  GenWindow(){}		
  
public:
  // We define additional ID's, starting from the last one used by the base class+1.
  // This way, we know the ID's are all unique for this particular target.
    enum {
    ID_ABOUT=FXMainWindow::ID_LAST,
	ID_NEW,
	ID_OPEN,
	ID_SAVE,
	ID_SAVEAS,
	ID_CUT,
	ID_COPY,
	ID_PASTE,
	ID_PRINT,
	ID_RECENTFILE,
	ID_COMPILE,
	ID_LINK,
	ID_RUN,
	ID_INDEX,
	ID_TOOLBARGRIP,
	ID_CREATE_MAIN,
	ID_CREATE_MENUS,
	ID_CREATE_MATRIX,
	ID_CREATE_BUTTON,
	ID_CREATE_ARROWBUTTON,
	ID_CREATE_CHECKBUTTON,
	ID_CREATE_LABEL,
	ID_CREATE_TEXTFIELD,
	ID_CREATE_COMBO,
	ID_CREATE_MULTILINE,
	ID_CREATE_RADIO,
	ID_CREATE_SPINNER,
	ID_CREATE_LIST,
	ID_CREATE_DIAL,
	ID_CREATE_SLIDER,
	ID_CREATE_TBUTTON,
	ID_CREATE_OPTION,
	ID_CREATE_LISTBOX,
	ID_CREATE_SCROLLBAR,
	ID_CREATE_GROUPBOX,
	ID_CREATE_MENUBUTTON,
	ID_CREATE_POPUP,
	ID_CREATE_HORFRAME,
	ID_CREATE_VERFRAME,
	ID_CREATE_SEARCH,
	ID_CREATE_REPLACE,
	ID_CREATE_TABLE,
	ID_CREATE_CLASS,
	ID_CODE,
	ID_DECLARE,
	ID_FONT_DECLARE,
	ID_TOOLBAR_STYLE,
    ID_TOOLBAR,
    ID_STATUS_BAR,
    ID_TOOLBOX
};

  // Message handlers
  long onCmdAbout(FXObject*,FXSelector,void*);
  long onCmdIndex(FXObject*,FXSelector,void*);
  long onCmdNew(FXObject*,FXSelector,void*);
  long onCmdOpen(FXObject*,FXSelector,void*);
  long onCmdSave(FXObject*,FXSelector,void*);
  long onCmdSaveAs(FXObject*,FXSelector,void*);
  long onCmdCompile(FXObject*,FXSelector,void*);
  long onCmdLink(FXObject*,FXSelector,void*);

  long onCmdCreateButton(FXObject*,FXSelector,void*);
  long onCmdCreateLabel(FXObject*,FXSelector,void*);
  long onCmdCreateTextField(FXObject*,FXSelector,void*);
  long onCmdCreateCombo(FXObject*,FXSelector,void*);
  long onCmdCreateMulti(FXObject*,FXSelector,void*);
  long onCmdCreateRadio(FXObject*,FXSelector,void*);
  long onCmdCreateSpinner(FXObject*,FXSelector,void*);
  long onCmdCreateListbox(FXObject*,FXSelector,void*);
  long onCmdCreateMain(FXObject*,FXSelector,void*);
  long onCmdCreateMenus(FXObject*,FXSelector,void*);
  long onCmdCreateMatrix(FXObject*,FXSelector,void*);
  long onCmdCreateCheckbutton(FXObject*,FXSelector,void*);
  long onCmdCreateArrowbutton(FXObject*,FXSelector,void*);
  long onCmdCreateDial(FXObject*,FXSelector,void*);
  long onCmdCreateSlider(FXObject*,FXSelector,void*);
  long onCmdCreateToggleButton(FXObject*,FXSelector,void*);
  long onCmdCreateOption(FXObject*,FXSelector,void*);
  long onCmdCreateListBox(FXObject*,FXSelector,void*);
  long onCmdCreateScrollBar(FXObject*,FXSelector,void*);
  long onCmdCreateGroupBox(FXObject*,FXSelector,void*);
  long onCmdCreateMenuButton(FXObject*,FXSelector,void*);
  long onCmdCreatePopup(FXObject*,FXSelector,void*);
  long onCmdCreateHorFrame(FXObject*,FXSelector,void*);
  long onCmdCreateVerFrame(FXObject*,FXSelector,void*);
  long onCmdCreateSearch(FXObject*,FXSelector,void*);
  long onCmdCreateReplace(FXObject*,FXSelector,void*);
  long onCmdCreateTable(FXObject*,FXSelector,void*);
  long onCmdCreateClass(FXObject*,FXSelector,void*);

public:
  GenWindow(FXApp* a);
  virtual void create();
  virtual ~GenWindow();
  };

/*******************************************************************************/

// Map
FXDEFMAP(GenWindow) GenWindowMap[]={
  //________Message_Type____________ID___________________Message_Handler________
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_ABOUT,GenWindow::onCmdAbout),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_INDEX,GenWindow::onCmdIndex),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_NEW,GenWindow::onCmdNew),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_OPEN,GenWindow::onCmdOpen),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_SAVE,GenWindow::onCmdSave),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_SAVEAS,GenWindow::onCmdSaveAs),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_COMPILE,GenWindow::onCmdCompile),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_LINK,GenWindow::onCmdLink),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_MAIN,GenWindow::onCmdCreateMain),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_BUTTON,GenWindow::onCmdCreateButton),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_LABEL,GenWindow::onCmdCreateLabel),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_TEXTFIELD,GenWindow::onCmdCreateTextField),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_COMBO,GenWindow::onCmdCreateCombo),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_MULTILINE,GenWindow::onCmdCreateMulti),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_RADIO,GenWindow::onCmdCreateRadio),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_SPINNER,GenWindow::onCmdCreateSpinner),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_LIST,GenWindow::onCmdCreateListbox),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_MENUS,GenWindow::onCmdCreateMenus),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_MATRIX,GenWindow::onCmdCreateMatrix),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_CHECKBUTTON,GenWindow::onCmdCreateCheckbutton),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_ARROWBUTTON,GenWindow::onCmdCreateArrowbutton),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_DIAL,GenWindow::onCmdCreateDial),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_SLIDER,GenWindow::onCmdCreateSlider),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_TBUTTON,GenWindow::onCmdCreateToggleButton),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_OPTION,GenWindow::onCmdCreateOption),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_LISTBOX,GenWindow::onCmdCreateListBox),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_SCROLLBAR,GenWindow::onCmdCreateScrollBar),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_GROUPBOX,GenWindow::onCmdCreateGroupBox),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_MENUBUTTON,GenWindow::onCmdCreateMenuButton),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_POPUP,GenWindow::onCmdCreatePopup),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_HORFRAME,GenWindow::onCmdCreateHorFrame),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_VERFRAME,GenWindow::onCmdCreateVerFrame),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_SEARCH,GenWindow::onCmdCreateSearch),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_REPLACE,GenWindow::onCmdCreateReplace),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_TABLE,GenWindow::onCmdCreateTable),
  FXMAPFUNC(SEL_COMMAND,GenWindow::ID_CREATE_CLASS,GenWindow::onCmdCreateClass),
 };

// Object implementation
FXIMPLEMENT(GenWindow,FXMainWindow,GenWindowMap,ARRAYNUMBER(GenWindowMap))

// Make some windows
GenWindow::GenWindow(FXApp* a):FXMainWindow(a,"Generator",NULL,NULL,DECOR_ALL,0,0,1100,750)
{
  mainFont=new FXFont(getApp(),AppFont,10,FONTWEIGHT_NORMAL,FONTSLANT_REGULAR,FONTENCODING_GREEK);
	
	genicon=new FXGIFIcon(getApp(),gen);
	comboicon=new FXGIFIcon(getApp(),ComboBox);
	checkicon=new FXGIFIcon(getApp(),CheckButton);
	buttonicon=new FXGIFIcon(getApp(),DrawnButton);
	textboxicon=new FXGIFIcon(getApp(),TextField);
	multilineicon=new FXGIFIcon(getApp(),CSText);
	spinnericon=new FXGIFIcon(getApp(),SpinBox);
	radioicon=new FXGIFIcon(getApp(),RadioBox);
	listboxicon=new FXGIFIcon(getApp(),List);
	arrowbuttonicon=new FXGIFIcon(getApp(),ArrowButton);
	mainicon=new FXGIFIcon(getApp(),ApplicationShell);
	matrixicon=new FXGIFIcon(getApp(),Matrix);
	menuicon=new FXGIFIcon(getApp(),MenuBar);
	labelicon=new FXGIFIcon(getApp(),Label);
	createicon=new FXGIFIcon(getApp(),creation);
	fonticon=new FXGIFIcon(getApp(),font);
	coloricon=new FXGIFIcon(getApp(),colors_gif);
	dialicon=new FXGIFIcon(getApp(),Dial);
	slidericon=new FXGIFIcon(getApp(),Slider);
	deleteicon=new FXGIFIcon(getApp(),delete_gif);
	
	//icons for main toolbar
	copyicon=new FXGIFIcon(getApp(),copy);
              newicon=new FXGIFIcon(getApp(),new_gif);
	openicon=new FXGIFIcon(getApp(),open_gif);
	saveicon=new FXGIFIcon(getApp(),save_gif);
	saveasicon=new FXGIFIcon(getApp(),saveas_gif);
	cuticon=new FXGIFIcon(getApp(),cut_gif);
	pasteicon=new FXGIFIcon(getApp(),paste_gif);
	printicon=new FXGIFIcon(getApp(),print_gif);
	
	codeicon=new FXGIFIcon(getApp(),code);
	propertiesicon=new FXGIFIcon(getApp(),properties);
	toolboxicon=new FXGIFIcon(getApp(),toolbox);
	
	setIcon(genicon);
	setMiniIcon(genicon);
	
	// Status bar
	FXStatusbar* statusbar=new FXStatusbar(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|STATUSBAR_WITH_DRAGCORNER);
	
	// Tooltip
	FXTooltip* tooltip= new FXTooltip(getApp());
	tooltip->setFont(mainFont);
	
	// Menubar
	menubar=new FXMenubar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	
	//Main Toolbar
	FXToolbarShell* dragshell1=new FXToolbarShell(this,FRAME_RAISED|FRAME_THICK);
             	mainTools=new FXToolbar(this,dragshell1,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	new FXToolbarGrip(mainTools,this,ID_TOOLBARGRIP);

	// Toolbox
	FXToolbarShell* dragshell2=new FXToolbarShell(this,FRAME_RAISED|FRAME_THICK);
	toolbox=new FXToolbar(this,dragshell2,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	new FXToolbarGrip(toolbox,this,ID_TOOLBARGRIP);			
	// MDI Client
	mdiclient=new FXMDIClient(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);

	// Icon for MDI Child
	mdiicon=new FXGIFIcon(getApp(),CommandDialog);

	// Make MDI Menu
	mdimenu=new FXMDIMenu(this,mdiclient);
	             		
	new FXMDIWindowButton(menubar,mdiclient,FXMDIClient::ID_MDI_MENUWINDOW,LAYOUT_LEFT);
	new FXMDIDeleteButton(menubar,mdiclient,FXMDIClient::ID_MDI_MENUCLOSE,FRAME_RAISED|LAYOUT_RIGHT);
	new FXMDIRestoreButton(menubar,mdiclient,FXMDIClient::ID_MDI_MENURESTORE,FRAME_RAISED|LAYOUT_RIGHT);
	new FXMDIMinimizeButton(menubar,mdiclient,FXMDIClient::ID_MDI_MENUMINIMIZE,FRAME_RAISED|LAYOUT_RIGHT);

	//sample window
	mdiSamples=new FXMDIChild(mdiclient,"Samples",NULL,mdimenu,LAYOUT_FIX_X|LAYOUT_FIX_Y,650,1,200,200);
	mtxSamples=new FXMatrix(mdiSamples,2,MATRIX_BY_COLUMNS|FRAME_RAISED);
	
	//text Window
	mdiCode=new FXMDIChild(mdiclient,"Code",codeicon,mdimenu,LAYOUT_FIX_X|LAYOUT_FIX_Y,1,1,540,550);
	editor=new FXText(mdiCode,this,ID_CODE,LAYOUT_FILL_X|LAYOUT_FILL_Y);
	editor->setFont(mainFont);
	editor->setTabColumns(3);
	
                // Show column number in status bar
	  new FXTextField(statusbar,4,editor,FXText::ID_CURSOR_COLUMN,FRAME_SUNKEN|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,1,1,0,0);
               // Caption before number
	  new FXLabel(statusbar,"Col:",NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
                // Show line number in status bar
	  new FXTextField(statusbar,4,editor,FXText::ID_CURSOR_ROW,FRAME_SUNKEN|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,1,1,0,0);
                // Caption before number
	  new FXLabel(statusbar,"Line:",NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);

              FXButton* btnNew=new FXButton(mainTools,"\tNew Project",newicon,this,ID_NEW,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnOpen=new FXButton(mainTools,"\tOpen Project",openicon,this,ID_OPEN,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnSave=new FXButton(mainTools,"\tSave Project",saveicon,this,ID_SAVE,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnSaveAs=new FXButton(mainTools,"\tSave As ...",saveasicon,this,ID_SAVEAS,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCut=new FXButton(mainTools,"\tCut",cuticon,editor,FXText::ID_CUT_SEL,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCopy=new FXButton(mainTools,"\tCopy",copyicon,editor,FXText::ID_COPY_SEL,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnPaste=new FXButton(mainTools,"\tPaste",pasteicon,editor,FXText::ID_PASTE_SEL,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnPrint=new FXButton(mainTools,"\tPrint Code",printicon,this,ID_PRINT,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	

  	FXButton* btnCreate_Main=new FXButton(toolbox,"\tMain Creator",mainicon,this,ID_CREATE_MAIN,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);           	
	FXButton* btnCreate_Menus=new FXButton(toolbox,"\tMenu Creator",menuicon,this,ID_CREATE_MENUS,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Matrix=new FXButton(toolbox,"\tMatrix Creator",matrixicon,this,ID_CREATE_MATRIX,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Button=new FXButton(toolbox,"\tButton Creator",buttonicon,this,ID_CREATE_BUTTON,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_ArrowButton=new FXButton(toolbox,"\tArrow Button Creator",arrowbuttonicon,this,ID_CREATE_ARROWBUTTON,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_CheckButton=new FXButton(toolbox,"\tCheck Button Creator",checkicon,this,ID_CREATE_CHECKBUTTON,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Label=new FXButton(toolbox,"\tLabel Creator",labelicon,this,ID_CREATE_LABEL,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Combo=new FXButton(toolbox,"\tComboBox Creator",comboicon,this,ID_CREATE_COMBO,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Text=new FXButton(toolbox,"\tText Field Creator",textboxicon,this,ID_CREATE_TEXTFIELD,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Spinner=new FXButton(toolbox,"\tSpinner Creator",spinnericon,this,ID_CREATE_SPINNER,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Radio=new FXButton(toolbox,"\tRadio button Creator",radioicon,this,ID_CREATE_RADIO,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_MlineTxt=new FXButton(toolbox,"\tText Multi line Creator",multilineicon,this,ID_CREATE_MULTILINE,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	FXButton* btnCreate_Listbox=new FXButton(toolbox,"\tList Box Creator",listboxicon,this,ID_CREATE_LIST,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,1,1,32,32);
	
	// ************* MENUS ****************
	// File menu
	filemenu=new FXMenuPane(this);
		new FXMenuCommand(filemenu,"&New\tCtl-N\tCreate new document.",NULL,this,ID_NEW);
		new FXMenuCommand(filemenu,"&Open\tCtl-O\tOpen document.",NULL,this,ID_OPEN);
		new FXMenuCommand(filemenu,"&Save\t\tSave Document",NULL,this,ID_SAVE);
		new FXMenuCommand(filemenu,"Save &As\t\tSave Document as",NULL,this,ID_SAVEAS);
		new FXMenuCommand(filemenu,"&Print\t\tPrint Document",NULL,this,ID_PRINT);
		new FXMenuCommand(filemenu,"&Quit\tCtl-Q\tQuit application.",NULL,getApp(),FXApp::ID_QUIT,0);
	new FXMenuTitle(menubar,"&File",NULL,filemenu);
	
	//Edit menu
	editmenu=new FXMenuPane(this);
		new FXMenuCommand(editmenu,"&Cut\t\tCut selected part",NULL,editor,FXText::ID_CUT_SEL);
		new FXMenuCommand(editmenu,"C&opy\t\tCopy selected part",NULL,editor,FXText::ID_COPY_SEL);
		new FXMenuCommand(editmenu,"&Paste\t\tPaste",NULL,editor,FXText::ID_PASTE_SEL);
		new FXMenuCommand(editmenu,"&Search\t\tSearch",NULL,editor,FXText::ID_SEARCH);
		new FXMenuCommand(editmenu,"&Replace\t\tReplace",NULL,editor,FXText::ID_REPLACE);
	new FXMenuTitle(menubar,"&Edit",NULL,editmenu);
	
	//Tools menu
	toolmenu=new FXMenuPane(this);
	
	mnuWindows=new FXMenuPane(this);
		new FXMenuCommand(mnuWindows,"&Window",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Main Window",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Root Window",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Scroll Window",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Popup",NULL,this,ID_CREATE_POPUP);
		new FXMenuCommand(mnuWindows,"&Status Bar",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Status Line",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&ToolTips",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Tool Bar",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Toolbar Grip",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Toolbar Shell",NULL,NULL,0);
		new FXMenuCommand(mnuWindows,"&Toolbar Tab",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Windows-Bars",NULL,mnuWindows);
	
	mnuMDIWin=new FXMenuPane(this);
		new FXMenuCommand(mnuMDIWin,"&Client",NULL,NULL,0);
		new FXMenuCommand(mnuMDIWin,"C&hild",NULL,NULL,0);
		new FXMenuCommand(mnuMDIWin,"&Delete Button",NULL,NULL,0);
		new FXMenuCommand(mnuMDIWin,"&Maximize Button",NULL,NULL,0);
		new FXMenuCommand(mnuMDIWin,"M&inimize Button",NULL,NULL,0);
		new FXMenuCommand(mnuMDIWin,"&Restore Button",NULL,NULL,0);
		new FXMenuCommand(mnuMDIWin,"&Window Button",NULL,NULL,0);
		new FXMenuCommand(mnuMDIWin,"M&enu",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&M&DI Windows",NULL,mnuMDIWin);
	
	mnuMenus=new FXMenuPane(this);
		new FXMenuCommand(mnuMenus,"Menu &Bar",NULL,NULL,0);
		new FXMenuCommand(mnuMenus,"Menu &Title",NULL,NULL,0);
		new FXMenuCommand(mnuMenus,"Menu &Pane",NULL,NULL,0);
		new FXMenuCommand(mnuMenus,"Menu &Command",NULL,NULL,0);
		new FXMenuCommand(mnuMenus,"Menu C&ascade",NULL,NULL,0);
		new FXMenuCommand(mnuMenus,"Menu Ca&ption",NULL,NULL,0);
		new FXMenuCommand(mnuMenus,"Menu &Separator",NULL,NULL,0);
		new FXMenuCommand(mnuMenus,"&Option Menu",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Menus",menuicon,mnuMenus);
	
	mnuColors=new FXMenuPane(this);
		new FXMenuCommand(mnuColors,"Color &Selector",NULL,NULL,0);
		new FXMenuCommand(mnuColors,"Color &Well",NULL,NULL,0);
		new FXMenuCommand(mnuColors,"Color &Dialog",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Colors",NULL,mnuColors);
	
	mnuCursors=new FXMenuPane(this);
		new FXMenuCommand(mnuCursors,"&Cursor",NULL,NULL,0);
		new FXMenuCommand(mnuCursors,"&GIF Cursor",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"Cu&rsors",NULL,mnuCursors);
	
	mnuIcons=new FXMenuPane(this);
		new FXMenuCommand(mnuIcons,"&Icon",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"Icon &Dict",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"Icon I&tem",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"Icon &List",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"Imag&e",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"Image &View",NULL,NULL,0);
		new FXMenuCommand(mnuIcons,"&BMP Icon",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"B&MP Image",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"BitM&ap Icon",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"&GIF Icon",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"G&IF Image",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"&JPEG Icon",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"J&PEG Image",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"&PNG Icon",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"P&NG Image",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"&XPM Icon",NULL,NULL,0);
	              new FXMenuCommand(mnuIcons,"XPM Ima&ge",NULL,NULL,0);
	 new FXMenuCascade(toolmenu,"Icons-I&mages",NULL,mnuIcons);
	
	 mnuFiles=new FXMenuPane(this);
	 	new FXMenuCommand(mnuFiles,"&File Dialog",NULL,NULL,0);
	 	new FXMenuCommand(mnuFiles,"File &Dict",NULL,NULL,0);
	 	new FXMenuCommand(mnuFiles,"File &Item",NULL,NULL,0);
	 	new FXMenuCommand(mnuFiles,"File &List",NULL,NULL,0);
		new FXMenuCommand(mnuFiles,"File &Selector",NULL,NULL,0);
		new FXMenuCommand(mnuFiles,"File St&ream",NULL,NULL,0);
		new FXMenuCommand(mnuFiles,"&Recent Files",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Files",NULL,mnuFiles);
	
	mnuDirs=new FXMenuPane(this);
		new FXMenuCommand(mnuDirs,"Dir &Box",NULL,NULL,0);
		new FXMenuCommand(mnuDirs,"Dir &Dialog",NULL,NULL,0);
		new FXMenuCommand(mnuDirs,"Dir &Item",NULL,NULL,0);
		new FXMenuCommand(mnuDirs,"Dir &List",NULL,NULL,0);
		new FXMenuCommand(mnuDirs,"Dir &Selector",NULL,NULL,0);
		new FXMenuCommand(mnuDirs,"Dr&ive Box",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Dir-Drives",NULL,mnuDirs);
	
	mnuFonts=new FXMenuPane(this);
		new FXMenuCommand(mnuFonts,"&Fonts",NULL,NULL,0);
		new FXMenuCommand(mnuFonts,"From &descriptor",NULL,NULL,0);
		new FXMenuCommand(mnuFonts,"Font D&ialog",NULL,NULL,0);
		new FXMenuCommand(mnuFonts,"Font &Selector",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"F&onts",NULL,mnuFonts);
	
	mnuBasic=new FXMenuPane(this);
		new FXMenuCommand(mnuBasic,"&Includes",NULL,NULL,0);
		new FXMenuCommand(mnuBasic,"&Main",mainicon,this,ID_CREATE_MAIN);
		new FXMenuCommand(mnuBasic,"&Class",NULL,this,ID_CREATE_CLASS);
		new FXMenuCommand(mnuBasic,"&Input Dialog",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"B&asics",NULL,mnuBasic);
		
//new FXMenuCommand(toolmenu,"M&enu",menuicon,this,ID_CREATE_MENUS);
	
	mnuLayMan=new FXMenuPane(this);
		new FXMenuCommand(mnuLayMan,"Ma&trix",matrixicon,this,ID_CREATE_MATRIX);
		new FXMenuCommand(mnuLayMan,"&Horizontal Frame",NULL,this,ID_CREATE_HORFRAME);
		new FXMenuCommand(mnuLayMan,"&Vertical Frame",NULL,this,ID_CREATE_VERFRAME);
		new FXMenuCommand(mnuLayMan,"&Horizontal Separator",NULL,NULL,0);
		new FXMenuCommand(mnuLayMan,"Ver&tical Separator",NULL,NULL,0);
		new FXMenuCommand(mnuLayMan,"&Packer",NULL,NULL,0);
		new FXMenuCommand(mnuLayMan,"T&op Window",NULL,NULL,0);
		new FXMenuCommand(mnuLayMan,"&Switcher",NULL,NULL,0);
		new FXMenuCommand(mnuLayMan,"&Group Box",NULL,this,ID_CREATE_GROUPBOX);
		new FXMenuCommand(mnuLayMan,"&Four Splitter",NULL,NULL,0);
		new FXMenuCommand(mnuLayMan,"F&rame",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"La&yout Managers",NULL,mnuLayMan);
	
	mnuButtons=new FXMenuPane(this);
		new FXMenuCommand(mnuButtons,"&Push Buttons",buttonicon,this,ID_CREATE_BUTTON);
		new FXMenuCommand(mnuButtons,"&ArrowButtons",arrowbuttonicon,this,ID_CREATE_ARROWBUTTON);
		new FXMenuCommand(mnuButtons,"&Check Buttons",checkicon,this,ID_CREATE_CHECKBUTTON);
		new FXMenuCommand(mnuButtons,"&Radio Buttons",radioicon,this,ID_CREATE_RADIO);
		new FXMenuCommand(mnuButtons,"&Toggle Buttons",NULL,this,ID_CREATE_TBUTTON);
		new FXMenuCommand(mnuButtons,"&Option",NULL,this,ID_CREATE_OPTION);
		new FXMenuCommand(mnuButtons,"Menu B&utton",NULL,this,ID_CREATE_MENUBUTTON);
	new FXMenuCascade(toolmenu,"&Buttons",NULL,mnuButtons);
	
	mnuSelectors=new FXMenuPane(this);
		new FXMenuCommand(mnuSelectors,"&Combo Boxes",comboicon,this,ID_CREATE_COMBO);
		new FXMenuCommand(mnuSelectors,"&Lists",listboxicon,this,ID_CREATE_LIST);
		new FXMenuCommand(mnuSelectors,"List &Boxes",NULL,this,ID_CREATE_LISTBOX);
		new FXMenuCommand(mnuSelectors,"List &Item",NULL,NULL,0);
		new FXMenuCommand(mnuSelectors,"&Tree List",NULL,NULL,0);
		new FXMenuCommand(mnuSelectors,"Tree List B&ox",NULL,NULL,0);
		new FXMenuCommand(mnuSelectors,"Tree It&em",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Selectors",NULL,mnuSelectors);
	
	mnuText=new FXMenuPane(this);	
		new FXMenuCommand(mnuText,"&Text Fields",textboxicon,this,ID_CREATE_TEXTFIELD);
		new FXMenuCommand(mnuText,"M&ulti Line Text",multilineicon,this,ID_CREATE_MULTILINE);
		new FXMenuCommand(mnuText,"&Labels",labelicon,this,ID_CREATE_LABEL);
		new FXMenuCommand(mnuText,"&Replace Dialog",NULL,this,ID_CREATE_REPLACE);
		new FXMenuCommand(mnuText,"&Search Dialog",NULL,this,ID_CREATE_SEARCH);
	new FXMenuCascade(toolmenu,"Te&xt",NULL,mnuText);
	
	mnuTabs=new FXMenuPane(this);
		new FXMenuCommand(mnuTabs,"&Tab Bar",NULL,NULL,0);
		new FXMenuCommand(mnuTabs,"Tab &Book",NULL,NULL,0);
		new FXMenuCommand(mnuTabs,"Tab &Item",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Tabs",NULL,mnuTabs);
	
	mnuTables=new FXMenuPane(this);
		new FXMenuCommand(mnuTables,"&Table",NULL,this,ID_CREATE_TABLE);
		new FXMenuCommand(mnuTables,"Table &Item",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"T&ables",NULL,mnuTables);
	
	mnuScrollers=new FXMenuPane(this);
		new FXMenuCommand(mnuScrollers,"&Scroll Bar",NULL,this,ID_CREATE_SCROLLBAR);
		new FXMenuCommand(mnuScrollers,"&Dial",dialicon,this,ID_CREATE_DIAL);
		new FXMenuCommand(mnuScrollers,"Scroll &Corner",NULL,NULL,0);
		new FXMenuCommand(mnuScrollers,"Scroll &Area",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"&Scrollers",NULL,mnuScrollers);	
	
	mnuIncDec=new FXMenuPane(this);
		new FXMenuCommand(mnuIncDec,"&Spinners",spinnericon,this,ID_CREATE_SPINNER);
		new FXMenuCommand(mnuIncDec,"S&liders",slidericon,this,ID_CREATE_SLIDER);
	new FXMenuCascade(toolmenu,"&Increasors-Decreasors",NULL,mnuIncDec);
	
	mnuOthers=new FXMenuPane(this);
		new FXMenuCommand(mnuOthers,"&Headers",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"Header &Item",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"&Shutter",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"Shutter &Item",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"S&uitcher",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"U&RL",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"&Message Box",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"&Print Dialog",NULL,NULL,0);
		new FXMenuCommand(mnuOthers,"Pr&ogress Bar",NULL,NULL,0);
	new FXMenuCascade(toolmenu,"O&thers",NULL,mnuOthers);
	
	new FXMenuTitle(menubar,"Create",NULL,toolmenu);
	
	genmenu=new FXMenuPane(this);
	new FXMenuCommand(genmenu,"Compile",NULL,this,ID_COMPILE);
	new FXMenuCommand(genmenu,"Link",NULL,this,ID_LINK);
	new FXMenuCommand(genmenu,"Run",NULL,this,ID_RUN);
	new FXMenuTitle(menubar,"&Run",NULL,genmenu);
	
	// Window menu
	windowmenu=new FXMenuPane(this);
	new FXMenuCommand(windowmenu,"Tile &Horizontally",NULL,mdiclient,FXMDIClient::ID_MDI_TILEHORIZONTAL);
	new FXMenuCommand(windowmenu,"Tile &Vertically",NULL,mdiclient,FXMDIClient::ID_MDI_TILEVERTICAL);
	new FXMenuCommand(windowmenu,"C&ascade",NULL,mdiclient,FXMDIClient::ID_MDI_CASCADE);
	new FXMenuCommand(windowmenu,"&Close",NULL,mdiclient,FXMDIClient::ID_MDI_CLOSE);
	new FXMenuCommand(windowmenu,"Close &All",NULL,mdiclient,FXMDIClient::ID_CLOSE_ALL_DOCUMENTS);
	FXMenuSeparator* sep1=new FXMenuSeparator(windowmenu);
	sep1->setTarget(mdiclient);
	sep1->setSelector(FXMDIClient::ID_MDI_ANY);
	new FXMenuCommand(windowmenu,NULL,NULL,mdiclient,FXMDIClient::ID_MDI_1);
	new FXMenuCommand(windowmenu,NULL,NULL,mdiclient,FXMDIClient::ID_MDI_2);
	new FXMenuCommand(windowmenu,NULL,NULL,mdiclient,FXMDIClient::ID_MDI_3);
	new FXMenuCommand(windowmenu,NULL,NULL,mdiclient,FXMDIClient::ID_MDI_4);
	new FXMenuTitle(menubar,"&Window",NULL,windowmenu);
  
	// Help menu
	helpmenu=new FXMenuPane(this);
	new FXMenuCommand(helpmenu,"&Index...",NULL,this,ID_INDEX,0);
	new FXMenuCommand(helpmenu,"&About FOX...",NULL,this,ID_ABOUT,0);
	new FXMenuTitle(menubar,"&Help",NULL,helpmenu,LAYOUT_RIGHT);
	
	// Recent files
	mrufiles.setTarget(this);
	mrufiles.setSelector(ID_RECENTFILE);
	filename="Untitled";
	
	dlgMain=new MainDialog(this);      dlgMain->setIcon(mainicon);
	dlgButton=new ButtonDialog(this); dlgButton->setIcon(buttonicon);
	dlgArrow=new ArrowDialog(this);	dlgArrow->setIcon(arrowbuttonicon);
	dlgCheck=new CheckDialog(this);	dlgCheck->setIcon(checkicon);
	dlgLabel=new LabelDialog(this);	dlgLabel->setIcon(labelicon);
	dlgRadio=new RadioDialog(this);	dlgRadio->setIcon(radioicon);
	dlgSpinner=new SpinnerDialog(this); dlgSpinner->setIcon(spinnericon);
	dlgTextField=new TextFieldDialog(this); dlgTextField->setIcon(textboxicon);
	dlgText=new TextDialog(this);	dlgText->setIcon(multilineicon);
	dlgMatrix=new MatrixDialog(this);	dlgMatrix->setIcon(matrixicon);
	dlgList=new ListDialog(this);	dlgList->setIcon(listboxicon);
	dlgCombo=new ComboDialog(this); dlgCombo->setIcon(comboicon);
	dlgDial=new DialDialog(this);
	dlgSlider=new SliderDialog(this);
	dlgTButton=new ToggleButtonDialog(this);
	dlgOption=new OptionDialog(this);
	dlgListBox=new ListBoxDialog(this);
	dlgScrollBar=new ScrollBarDialog(this);
	dlgGroupBox=new GroupDialog(this);
	dlgMnuButton=new MenuButtonDialog(this);
	dlgPopup=new PopupDialog(this);
	dlgHorFrame=new HorFrameDialog(this);
	dlgVerFrame=new VerFrameDialog(this);
	dlgSearch=new SearchDialog(this);
	dlgReplace=new ReplaceDialog(this);
	dlgTable=new TableDialog(this);
	dlgClass=new ClassDialog(this);
}

// Clean up
GenWindow::~GenWindow(){
  delete filemenu;
  delete editmenu;
  delete toolmenu;
  delete mnuWindows;
  delete mnuMDIWin;
  delete mnuColors;
  delete mnuMenus;
  delete mnuCursors;
  delete mnuIcons;
  delete mnuFiles;
  delete mnuFonts;
  delete mnuBasic;
  delete mnuLayMan;
  delete mnuButtons;
  delete mnuSelectors;
  delete mnuText;
  delete mnuIncDec;
  delete genmenu;
  delete windowmenu;
  delete helpmenu;
  delete mnuDirs;
  delete mnuTabs;
  delete mnuTables;
  delete mnuScrollers;
  delete mnuOthers;
  }

// Start
void GenWindow::create()
{
  FXMainWindow::create();
  show();
}

// About
long GenWindow::onCmdAbout(FXObject*,FXSelector,void*){
  FXMessageBox::information(this,MBOX_OK,"About Generator","Generates C++ code\nwith the help of FOX Library\nWritten by Anastasios Sarris");
  return 1;
  }

long GenWindow::onCmdIndex(FXObject*,FXSelector,void*)
{

	return 1;
}

// Load file
FXbool GenWindow::loadFile(const FXString& file)
{
  struct stat info;
  FILE *fp;
  char *text;
  FXuint n,i,j;
  if(stat(file.text(),&info)!=0)
  {
    FXMessageBox::error(this,MBOX_OK,"Error Loading File","Non-existing file: %s",file.text());
    return FALSE;
   }
  fp=fopen(file.text(),"r");
  if(!fp)
  {
    FXMessageBox::error(this,MBOX_OK,"Error Loading File","Unable to open file: %s",file.text());
    return FALSE;
  }
  getApp()->beginWaitCursor();
  // Under WIN32, when the file is opened in text mode, fread() converts CR/LF pairs
  // to single LF characters; so the number of items returned by fread() will be less
  // than the file size reported by info.st_size.
  FXCALLOC(&text,FXchar,info.st_size+1);
  n=fread(text,1,info.st_size,fp);

  // Strip carriage returns
  if(stripcr)
  {
    for(i=j=0; j<n; j++){
      if(text[j]!='\r') text[i++]=text[j];
  }
    text[i]='\0';
    n=i;
  }
  editor->setText(text,n);
  editor->setModified(FALSE);
  FXFREE(&text);
  fclose(fp);
  getApp()->endWaitCursor();
  undolist.clear();
  return TRUE;
}


// Save file
FXbool GenWindow::saveFile(const FXString& file){
  FILE *fp;
  char *text;
  FXuint n,len;
  fp=fopen(file.text(),"w");
  if(!fp){
    FXMessageBox::error(this,MBOX_OK,"Error Saving File","Unable to open file: %s",file.text());
    return FALSE;
    }
  getApp()->beginWaitCursor();
  len=editor->getLength();
  FXCALLOC(&text,FXchar,len);
  editor->getText(text,len);
  n=fwrite(text,1,len,fp);
  if(n!=len){
    FXMessageBox::error(this,MBOX_OK,"Error Saving File","Unable to save entire file: %s",file.text());
    }
  fclose(fp);
  FXFREE(&text);
  editor->setModified(FALSE);
  getApp()->endWaitCursor();
  return TRUE;
  }

FXbool GenWindow::saveChanges(){
  FXuint answer;
  if(editor->isModified()){
    answer=FXMessageBox::question(this,MBOX_YES_NO_CANCEL,"Unsaved Document","Save current document to file?");
    if(answer==MBOX_CLICKED_CANCEL) return FALSE;
    if(answer==MBOX_CLICKED_YES){
      if(!namechanged){
        FXFileDialog savedialog(this,"Save Document");
        savedialog.setSelectMode(SELECTFILE_ANY);
        savedialog.setFilename(filename);
        if(!savedialog.execute()) return FALSE;
        if(FXFile::exists(savedialog.getFilename())){
          if(MBOX_CLICKED_NO==FXMessageBox::question(this,MBOX_YES_NO,"Overwrite Document","Overwrite existing document: %s?",savedialog.getFilename().text())) return FALSE;
          }
        filename=savedialog.getFilename();
        }
      saveFile(filename);
      }
    }
  return TRUE;
  }

 // New
long GenWindow::onCmdNew(FXObject*,FXSelector,void*)
{
  FXuint answerNew;
  if ((editor->isModified()) || (editor->getText()!=""))
  {
	answerNew=FXMessageBox::question(this,MBOX_YES_NO,"Unsaved Document","Continue?");
	if(answerNew==MBOX_CLICKED_YES)
	{
		editor->setText("");
		filename="";
		mdiCode->setTitle("Code");
		return FALSE;
	}
	if(answerNew==MBOX_CLICKED_NO) return 1;
  }
/*	mdiCode=new FXMDIChild(mdiclient,"Code",codeicon,mdimenu,LAYOUT_FIX_X|LAYOUT_FIX_Y,1,1,540,550);
	editor=new FXText(mdiCode,this,ID_CODE,LAYOUT_FILL_X|LAYOUT_FILL_Y);
	editor->setFont(mainFont);
	editor->setTabColumns(3);
	mdiCode->create();*/
	return 1;
}

long GenWindow::onCmdOpen(FXObject*,FXSelector,void*)
{
	  FXFileDialog opendialog(this,"Open Document");
	  opendialog.setFilename(filename);
	  opendialog.setPatternList(filepatterns);
	  if(opendialog.execute())
	  {
		filename=opendialog.getFilename();
//		filelist->setCurrentFile(filename);
//		mrufiles.appendFile(filename);
		loadFile(filename);
		namechanged=TRUE;
		mdiCode->setTitle(filename);
	  }
              return 1;
}

long GenWindow::onCmdSave(FXObject* sender,FXSelector sel ,void* ptr)
{
	if(!namechanged) return onCmdSaveAs(sender,sel,ptr);
	saveFile(filename);
	return 1;
}

// Save As
long GenWindow::onCmdSaveAs(FXObject*,FXSelector,void*)
{
  FXFileDialog savedialog(this,"Save Document");
  savedialog.setSelectMode(SELECTFILE_ANY);
  savedialog.setFilename(filename);
  if(savedialog.execute()){
    if(FXFile::exists(savedialog.getFilename()))
    {
      if(MBOX_CLICKED_NO==FXMessageBox::question(this,MBOX_YES_NO,"Overwrite Document","Overwrite existing document: %s?",savedialog.getFilename().text())) return 1;
    }
    filename=savedialog.getFilename();
//    filelist->setCurrentFile(filename);
//    mrufiles.appendFile(filename);
    saveFile(filename);
    namechanged=TRUE;
    }
  return 1;
}

long GenWindow::onCmdCompile(FXObject*,FXSelector,void*)
{             FXString CompileThe="gcc -c "+filename;
	const char* CompileStr=CompileThe.text();
	system(CompileStr);
	return 1;
}

long GenWindow::onCmdLink(FXObject*,FXSelector,void*)
{
	
//             FXString CompileThe="gcc -c "+filename;
//	const char* CompileStr=CompileThe.text();
//	system(CompileStr);
	return 1;
}

long GenWindow::onCmdCreateMain(FXObject*,FXSelector,void*)
{
	dlgMain->show();
	return 1;
}

long GenWindow::onCmdCreateButton(FXObject*,FXSelector,void*)
{
	dlgButton->show();
	return 1;
}

long GenWindow::onCmdCreateArrowbutton(FXObject*,FXSelector,void*)
{
	dlgArrow->show();
	return 1;
}

long GenWindow::onCmdCreateCheckbutton(FXObject*,FXSelector,void*)
{
	dlgCheck->show();
	return 1;
}

long GenWindow::onCmdCreateLabel(FXObject*,FXSelector,void*)
{
	dlgLabel->show();
	return 1;
}

long GenWindow::onCmdCreateMenus(FXObject*,FXSelector,void*)
{
//	system("/root/fox-0.99.160/mytests/combobox");
	return 1;
}

long GenWindow::onCmdCreateRadio(FXObject*,FXSelector,void*)
{
	dlgRadio->show();
	return 1;
}

long GenWindow::onCmdCreateSpinner(FXObject*,FXSelector,void*)
{
	dlgSpinner->show();
	return 1;
}

long GenWindow::onCmdCreateTextField(FXObject*,FXSelector,void*)
{
	dlgTextField->show();
	return 1;
}

long GenWindow::onCmdCreateMulti(FXObject*,FXSelector,void*)
{
	dlgText->show();
	return 1;
}

long GenWindow::onCmdCreateMatrix(FXObject*,FXSelector,void*)
{
	dlgMatrix->show();
	return 1;
}

long GenWindow::onCmdCreateListbox(FXObject*,FXSelector,void*)
{
	dlgList->show();
	return 1;
}

long GenWindow::onCmdCreateCombo(FXObject*,FXSelector,void*)
{
	dlgCombo->show();
	return 1;
}

long GenWindow::onCmdCreateDial(FXObject*,FXSelector,void*)
{
	dlgDial->show();
	return 1;
}

long GenWindow::onCmdCreateSlider(FXObject*,FXSelector,void*)
{
	dlgSlider->show();
	return 1;
}

long GenWindow::onCmdCreateToggleButton(FXObject*,FXSelector,void*)
{
	dlgTButton->show();
	return 1;
}

long GenWindow::onCmdCreateOption(FXObject*,FXSelector,void*)
{
	dlgOption->show();
	return 1;
}

long GenWindow::onCmdCreateListBox(FXObject*,FXSelector,void*)
{
	dlgListBox->show();
	return 1;
}

long GenWindow::onCmdCreateScrollBar(FXObject*,FXSelector,void*)
{
	dlgScrollBar->show();
	return 1;
}

long GenWindow::onCmdCreateGroupBox(FXObject*,FXSelector,void*)
{
	dlgGroupBox->show();
	return 1;
}

long GenWindow::onCmdCreateMenuButton(FXObject*,FXSelector,void*)
{
	dlgMnuButton->show();
	return 1;
}

long GenWindow::onCmdCreatePopup(FXObject*,FXSelector,void*)
{
	dlgPopup->show();
	return 1;
}

long GenWindow::onCmdCreateHorFrame(FXObject*,FXSelector,void*)
{
	dlgHorFrame->show();
	return 1;
}

long GenWindow::onCmdCreateVerFrame(FXObject*,FXSelector,void*)
{
	dlgVerFrame->show();
	return 1;
}

long GenWindow::onCmdCreateSearch(FXObject*,FXSelector,void*)
{
	dlgSearch->show();
	return 1;
}

long GenWindow::onCmdCreateReplace(FXObject*,FXSelector,void*)
{
	dlgReplace->show();
	return 1;
}

long GenWindow::onCmdCreateTable(FXObject*,FXSelector,void*)
{
	dlgTable->show();
	return 1;
}

long GenWindow::onCmdCreateClass(FXObject*,FXSelector,void*)
{
	dlgClass->show();
	return 1;
}

int main(int argc,char *argv[]){

  FXApp application("Generator","Anastasios Sarris");
  application.init(argc,argv);
  new GenWindow(&application);
  application.create();
  return application.run();
  }

